# tcia_utils 
This package contains functions to simplify common tasks one might perform when interacting with The Cancer Imaging Archive (TCIA) via Jupyter/Python.
Learn more about TCIA and its open-access datasets at https://www.cancerimagingarchive.net/.